function cc = TenRot(c,iaxis,theta)
%function cc = TenRot(c,iaxis,theta)
% Adapted from Shearer/Crampin code (below)
%
%	c - original fourth order tensor, c(3,3,3,3)
%	iaxis - axis about which to rotate
%	theta - angle to rotate
%
%	A Companion script for Oliver S. Boyd, An Efficient Matlab Script to Calculate 
%	Heterogeneous Anisotropically Elastic Wave Propagation in Three Dimensions
%	
%	Adopted from the fortran code written by Shearer and Crampin
%

na = length(theta);
pirad = pi/180;

if na > 1
	sz = size(c);
	cc = zeros(sz);
	r = zeros(3,3,na);

	for a = 1:na
		for i=1:3
			for j=1:3
				if (i == iaxis(a) & j == iaxis(a))
					r(i,j,a) = 1;
				elseif (i == iaxis(a) | j == iaxis(a))
					r(i,j,a) = 0;
				elseif (i == j)
					r(i,j,a) = cos(pirad*theta(a));
				elseif (i > j)
					r(i,j,a) = sin(pirad*theta(a));
				else
					r(i,j,a) = -sin(pirad*theta(a));
				end
			end
		end
	end
	for ii=1:3
   	   for jj=1:3
      	      for kk=1:3
         	 for ll=1:3
            	    for i=1:3
               	       for j=1:3
                  	  for k=1:3
                     	     for l=1:3
				cp = squeeze(cc(ii,jj,kk,ll,:));
				cn = squeeze(c(i,j,k,l,:));
				ri = squeeze(r(ii,i,:));
				rj = squeeze(r(jj,j,:));
				rk = squeeze(r(kk,k,:));
				rl = squeeze(r(ll,l,:));
                        	cc(ii,jj,kk,ll,:) = cp + cn.*ri.*rj.*rk.*rl;
                     	     end
                  	  end
               	       end
            	    end
         	 end
      	      end
   	   end
	end

else
	sz = size(c);
	cc = zeros(sz);
	r = zeros(3,3);

	for i=1:3
		for j=1:3
			if (i == iaxis & j == iaxis)
				r(i,j) = 1;
			elseif (i == iaxis | j == iaxis)
				r(i,j) = 0;
			elseif (i == j)
				r(i,j) = cos(pirad*theta);
			elseif (i > j)
				r(i,j) = sin(pirad*theta);
			else
				r(i,j) = -sin(pirad*theta);
			end
		end
	end
	for ii=1:3
   	   for jj=1:3
      	      for kk=1:3
         	 for ll=1:3
            	    for i=1:3
               	       for j=1:3
                  	  for k=1:3
                     	     for l=1:3
                       	        cc(ii,jj,kk,ll) = cc(ii,jj,kk,ll)+c(i,j,k,l)*r(ii,i)*r(jj,j)*r(kk,k).*r(ll,l);
                     	     end
                  	  end
               	       end
            	    end
         	 end
      	      end
   	   end
	end
end

return

%Original program by Shearer and Crampin
%c ROTATE rotates an elastic tensor about a specified angle
      %SUBROUTINE ROTATE(c,cc,iaxis,theta)
      %implicit double precision (a-h,o-z)
      %dimension c(3,3,3,3),cc(3,3,3,3),r(3,3)
      %pirad=3.14159265d0/180.0d0
%c
      %do 6 i=1,3
         %do 5 j=1,3
            %if (i.eq.iaxis.and.j.eq.iaxis) then
               %r(i,j)=1.
            %else if (i.eq.iaxis.or.j.eq.iaxis) then
               %r(i,j)=0.
            %else if (i.eq.j) then
               %r(i,j)=cos(pirad*theta)
            %else if (i.gt.j) then
               %r(i,j)=sin(pirad*theta)
            %else
               %r(i,j)=-sin(pirad*theta)
            %end if
%5        continue
%6     continue
%c
      %do 80 ii=1,3
      %do 70 jj=1,3
      %do 60 kk=1,3
      %do 50 ll=1,3
%c
         %cc(ii,jj,kk,ll)=0.0d0
         %do 40 i=1,3
         %do 30 j=1,3
         %do 20 k=1,3
         %do 10 l=1,3
            %cc(ii,jj,kk,ll)=cc(ii,jj,kk,ll)+c(i,j,k,l)*r(ii,i)*r(jj,j)
     %&                      *r(kk,k)*r(ll,l)
%10       continue
%20       continue
%30       continue
%40       continue
%c
%50    continue
%60    continue
%70    continue
%80    continue
%c
%900   return
      %end
